summaryrefslogtreecommitdiffstats
path: root/korganizer/koeventview.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koeventview.h')
-rw-r--r--korganizer/koeventview.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/korganizer/koeventview.h b/korganizer/koeventview.h
index 69f6377f..0a29e0c9 100644
--- a/korganizer/koeventview.h
+++ b/korganizer/koeventview.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef _KOEVENTVIEW_H
#define _KOEVENTVIEW_H
@@ -55,16 +55,17 @@ class TQPopupMenu;
class KOEventView : public KOrg::BaseView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a view.
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
* @param parent is the parent TQWidget.
* @param name is the view name.
*/
- KOEventView(Calendar *cal,TQWidget *parent=0,const char *name=0);
+ KOEventView(Calendar *cal,TQWidget *tqparent=0,const char *name=0);
/**
* Destructor. Views will do view-specific cleanups here.
@@ -55,16 +55,17 @@ class TQPopupMenu;
* @param cal is a pointer to the calendar object from which events
* will be retrieved for display.
- * @param parent is the parent TQWidget.
+ * @param tqparent is the tqparent TQWidget.
* @param name is the view name.
*/